#################################################################
#    Compiled by Frost et al. (2001) - Journal of Petrology     #
#################################################################


Frost_2008<-function(plot.txt=getOption("gcd.plot.text"),clssf=FALSE,GUI=FALSE){
    plate<-as.list(1:4)
    plate.data<-as.list(1:4)
    plate$nrow<-2
    plate$ncol<-2
    plate$title<-"Granite tectonic discrimination - Frost & Frost (2008)"
    plate$plot.name<-"Frost + Frost (2008)"
    plate$plot.position<-103.5
    cex.axis<-1.2
    cex.lab<-1.35
    
    # Calculations
    
    # Fe-index  - just formula here
    koef<-0.46
    FeNr<-"FeOt/(FeOt+MgO)"
    
    # Modified alkali-lime index (MALI) - just formula here
    MALI<-"Na2O+K2O-CaO"

    # Aluminium saturation index
    p<-milli[,"P2O5"]
    p[is.na(p)]<-0
    ASI<-milli[,"Al2O3"]/(2*(milli[,"CaO"]-1.67*p)+milli[,"Na2O"]+milli[,"K2O"])
    #ASI_orig<-milli[,"Al2O3"]/(milli[,"CaO"]-1.67*p+milli[,"Na2O"]+milli[,"K2O"]) 

    # Alkalinity index
    AI <-(milli[,"Al2O3"]-(milli[,"Na2O"]+milli[,"K2O"]))/1000 
    
    # CIPW normative values
    # Feldspathoid silica-saturation index (FSSI)
    if(!diagram.testing){ #  So businness as usual
        norma<-CIPW(WR,complete.results = TRUE)
        norma[is.na(norma)]<-0
        
        # Add if some variable missing completely
        what<-rep(0,nrow(norma))
        norma<-addOn("Q",what,where=norma)
        norma<-addOn("Lc",what,where=norma)
        norma<-addOn("Ne",what,where=norma)
        norma<-addOn("Kp",what,where=norma)
    }else{ # Do not calculate CIPW norm upon GCDkit startup
        norma<-matrix(nrow=nrow(WR),ncol=4) # Dummy matrix
        colnames(norma)<-c("Q","Lc","Ne","Kp")
        rownames(norma)<-rownames(WR)
    }
    
    FSSI<-(norma[,"Q"]-(norma[,"Lc"]+2*(norma[,"Ne"]+norma[,"Kp"])))/100 # Fixed brackets, obviously the whole thing should be divided by 100
    
    ############
    # Plot 1   #
    ############
    x<-48:75

    plate.data[[1]]$x<-"SiO2"
    plate.data[[1]]$y<-FeNr

    temp1<-list(
        axis1=list("axis",side=1,at=c(50,55,60,65,70,75,80),labels=c("50","55","60","65","70","75","80"),cex.axis=cex.axis,cex.lab=cex.lab,las=0,hadj=NA,padj=NA,lty="solid"),
        axis2=list("axis",side=2,at=c(0,0.2,0.4,0.6,0.8,1),labels=c("0","0.2","0.4","0.6","0.8","1"),cex.axis=cex.axis,cex.lab=cex.lab,las=0,hadj=NA,padj=NA,lty="solid"),
        box=list("box",which="plot",col="black",lwd=1),
        lines1=list("lines",x=x,y=koef+0.005*x,col=plt.col[2]),
        GCDkit=list("NULL",plot.type="binary",plot.name="SiO2 - FeNr (Frost & Frost 2008)")
    )

    temp2<-list(
        text1=list("text",x=60,y=0.9,text="ferroan",adj=0.5,col=plt.col[2]),
        text2=list("text",x=60,y=0.6,text="magnesian",adj=0.5,col=plt.col[2])
    )
    
    if(getOption("gcd.plot.text")) temp<-c(temp1,temp2) else temp<-temp1
     
    plate[[1]]<-list(demo=list(fun="plot",call=list(xlim=c(48,80),ylim=c(0,1),main="",bg="white",fg="black",axes=FALSE,xlab=annotate("SiO2"),ylab="FeOt/(FeOt + MgO)",cex.lab=cex.lab,diagram="Frost_2008",arguments=list(which=1),new=FALSE),template=temp))
    
    ############
    # Plot 2   #
    ############
    x<-48:75

    plate.data[[2]]$x<-"SiO2"
    plate.data[[2]]$y<-MALI
    
    temp1<-list(
        axis1=list("axis",side=1,at=c(50,55,60,65,70,75,80),labels=c("50","55","60","65","70","75","80"),cex.axis=cex.axis,cex.lab=cex.lab,las=0,hadj=NA,padj=NA,lty="solid"),
        axis2=list("axis",side=2,at=c(-8,-4,0,4,8,12),labels=c("-8","-4","0","4","8","12"),cex.axis=cex.axis,cex.lab=cex.lab,las=0,hadj=NA,padj=NA,lty="solid"),
        box=list("box",which="plot",col="black",lwd=1),
        lines1=list("lines",x=x,y=-41.86+1.112*x-0.00572*x^2,col=plt.col[2]),
        lines2=list("lines",x=x,y=-44.72+1.094*x-0.00527*x^2,col=plt.col[2]),
        lines3=list("lines",x=x,y=-45.36+1.0043*x-0.00427*x^2,col=plt.col[2]),
        GCDkit=list("NULL",plot.type="binary",plot.name="SiO2 - MALI (Frost & Frost 2008)")
    )

    temp2<-list(
        text1=list("text",x=55,y=7.7,text="alkalic",cex=1,col=plt.col[2]),
        text2=list("text",x=60,y=3.5,text="alkali-calcic",cex=1,col=plt.col[2],srt=25),
        text3=list("text",x=60,y=1,text="calc-alkalic",cex=1,col=plt.col[2],srt=30),
        text4=list("text",x=65,y=-2,text="calcic",cex=1,col=plt.col[2])
    )
    
    if (getOption("gcd.plot.text")) temp<-c(temp1,temp2) else temp<-temp1
     
    plate[[2]]<-list(demo=list(fun="plot",call=list(xlim=c(50,80),ylim=c(-8,12),main="",bg="white",fg="black",axes=FALSE,xlab=annotate("SiO2"),ylab=annotate(paste("MALI: ",MALI,"(wt. %)")),cex.lab=cex.lab,diagram="Frost_2008",arguments=list(which=2),new=FALSE),template=temp))

    ############
    # Plot 3   #
    ############
    x<-48:75
   
    plate.data[[3]]$x<-"SiO2"
    plate.data[[3]]$y<-ASI
    
    temp1<-list(
        axis1=list("axis",side=1,at=c(50,55,60,65,70,75,80),labels=c("50","55","60","65","70","75","80"),cex.axis=cex.axis,cex.lab=cex.lab,las=0,hadj=NA,padj=NA,lty="solid"),
        axis2=list("axis",side=2,at=seq(0.7,1.5,0.1),labels=seq(0.7,1.5,0.1),cex.axis=cex.axis,cex.lab=cex.lab,las=0,hadj=NA,padj=NA,lty="solid"),
        box=list("box",which="plot",col="black",lwd=1),
        lines1=list("abline",h=1,col=plt.col[2]),
        GCDkit=list("NULL",plot.type="binary",plot.name="SiO2 - ASI (Frost & Frost 2008)")
    )

    temp2<-list(
        text1=list("text",x=51,y=0.75,text="metaluminous",adj=0,cex=1,col=plt.col[2]),
        text2=list("text",x=51,y=1.03,text="peraluminous",adj=0,cex=1,col=plt.col[2])
    )
    
    if (getOption("gcd.plot.text")) temp<-c(temp1,temp2) else temp<-temp1
     
    plate[[3]]<-list(demo=list(fun="plot",call=list(xlim=c(50,80),ylim=c(0.7,1.3),main="",bg="white",fg="black",axes=FALSE,xlab=annotate("SiO2"),ylab="ASI",cex.lab=cex.lab,diagram="Frost_2008",arguments=list(which=3),new=FALSE),template=temp))

    ############
    # Plot 4   #
    ############ 

    plate.data[[4]]$x<-FSSI
    plate.data[[4]]$y<-AI[names(FSSI)]
    
    temp1<-list(
        axis1=list("axis",side=1,at=seq(-1,1,0.2),labels=seq(-1,1,0.2),cex.axis=cex.axis,cex.lab=cex.lab,las=0,hadj=NA,padj=NA,lty="solid"),
        axis2=list("axis",side=2,at=seq(-0.1,0.3,0.05),labels=seq(-0.10,0.3,0.05),cex.axis=cex.axis,cex.lab=cex.lab,las=0,hadj=NA,padj=NA,lty="solid"),
        box=list("box",which="plot",col="black",lwd=1),
        lines1=list("abline",h=0,col=plt.col[2]),
        lines2=list("abline",v=0,col=plt.col[2]),
        GCDkit=list("NULL",plot.type="binary",plot.name="FSSI - AI (Frost & Frost 2008)")
    )

    temp2<-list(
        text1=list("text",x=-0.5,y=0.28,text="silica-undersaturated",adj=0.5,cex=1.3,col=plt.col[1]),
        text2=list("text",x=0.5,y=0.28,text="silica-saturated",adj=0.5,cex=1.3,col=plt.col[1]),
        text3=list("text",x=-0.5,y=0.25,text="metaluminous\n(rarely peraluminous)",adj=0.5,cex=1,col=plt.col[2]),
        text4=list("text",x=0.5,y=0.25,text="metaluminous &\nperaluminous",adj=0.5,cex=1,col=plt.col[2]),
        #text5=list("text",x=-0.5,y=0.95,text="peralkaline",adj=0.5,cex=1,col=plt.col[2]),
        #text6=list("text",x=0.5,y=0.95,text="peralkaline",adj=0.5,cex=1,col=plt.col[2]),
        text7=list("text",x=0.9,y=-0.05,text="peralkaline",adj=0.5,cex=1.3,srt=90,col=plt.col[1]),
        text8=list("text",x=0.9,y=0.15,text="meta/peraluminous",adj=0.5,cex=1.3,srt=90,col=plt.col[1])
    )
    
    if (getOption("gcd.plot.text")) temp<-c(temp1,temp2) else temp<-temp1
    plate[[4]]<-list(demo=list(fun="plot",call=list(xlim=c(-1,1),ylim=c(-0.10,0.30),main="",bg="white",fg="black",axes=FALSE,xlab=annotate("FSSI: (Q-(Lc+2*(Ne+Kp)))/100"),ylab=annotate("AI: Al2O3-(Na2O + K2O) (mol. %)"),cex.lab=cex.lab,diagram="Frost_2008",arguments=list(which=4),new=FALSE),template=temp))
    
    assign("plate",plate,.GlobalEnv)
    assign("plate.data",plate.data,.GlobalEnv)
    
    ##############################
    #  Prepare return values     #
    ##############################
    FeNr<-calcCore(FeNr)$r
    MALI<-calcCore(MALI)$r

    results<-cbind(FeNr,MALI,ASI,AI)
    results<-addOn("FSSI",FSSI,results)# Caution, for FSSI some samples may be missing
    colnames(results)<-c("Fe-number","MALI","ASI","AI","FSSI") 

    ##############################
    # Classification algorithm   #
    ##############################
    if(clssf){    
        name<-vector()
        for (i in 1:nrow(WR)){
            mis<-F
            if (!is.na(FeNr[i])){
                if (FeNr[i]<(koef+0.005*WR[i,"SiO2"])) tmpa<-"magnesian" else tmpa<-"ferroan"
            }else{
                tmpa<-"missing data"; mis<-TRUE
            }
        
            if(!is.na(MALI[i])){
                if(MALI[i]<(-41.86+1.112*WR[i,"SiO2"]-0.00572*WR[i,"SiO2"]^2))  tmpb<-"alkali-calcic" else tmpb<-"alkalic"
                if(MALI[i]<(-44.72+1.094*WR[i,"SiO2"]-0.00527*WR[i,"SiO2"]^2))  tmpb<-"calc-alkalic"
                if(MALI[i]<(-45.36+1.0043*WR[i,"SiO2"]-0.00427*WR[i,"SiO2"]^2)) tmpb<-"calcic"
            }else{
                tmpb<-"missing data"; mis<-TRUE
            }
        
            if (!(is.na(ASI[i]) | is.na(milli[i,"K2O"]) | is.na(milli[i,"Na2O"]) | is.na(milli[i,"Al2O3"]))){
                if(ASI[i]>1){
                    tmpc<-"peraluminous"
                }else{
                    if (milli[i,"K2O"]+milli[i,"Na2O"]<milli[i,"Al2O3"]) tmpc<-"metaluminous" else tmpc<-"peralkaline"
                }
            }else{
                tmpc<-"missing data"; mis<-TRUE
            }
        
            if (!(is.na(FSSI[i]))){
                if (FSSI[i]>=0) tmpd<-"silica-saturated" else tmpd<-"silica-undersaturated"
            }else{
                tmpd<-"missing data"; mis<-TRUE
            }
            
            if (mis) name<-c(name,"unclassified") else name<-c(name,paste(tmpa,tmpb,tmpc,tmpd,sep="; "))
        }
       
        names(name)<-rownames(WR)
        if (!getOption("gcd.shut.up")) {
            print(results)
            cat("Samples classified by: Frost & Frost (2008)","\n")
            print(tapply(name, factor(name), length))
            results<-name
            cat("to view classification of individual samples type 'results'\n\n")
            flush.console()
        }
        
        if(GUI){
            x<-winDialog(type="yesno","Append current classification to labels?")
            if(x=="YES"){
                col.name<-winDialogString("Name of the new column","Frost_2008")
                labels<<-cbind(labels,results)
                colnames(labels)[ncol(labels)]<-col.name
                .assignWithNamespaceHard("labels",labels)
            }
        }
    }else{
        if (!getOption("gcd.shut.up")) print(results)
    }
    assign("results",results,.GlobalEnv)
    invisible()
}
