### Name: FIGARO
### Title: Figures as R objects
### Aliases: FIGARO plot.default
### Keywords: hplot iplot aplot color internal

### ** Examples

## Not run: 
##D # create a new figure object
##D p <- figaro(plot)
##D # plot some data
##D p$draw(runif(10), runif(10))
##D # change the main title
##D p$set(main="Figaro Demonstration")
##D 
##D # a histogram
##D h <- figaro(hist)
##D h$draw(rnorm(2000), col="blue")
##D # .. a better colour
##D h$set(col="yellow")
##D 
##D # using figaro with a style sheet
##D # create figure based on demo style from stylesheet 'fss'
##D d <- figaro(demo, fss="fss")
##D # draw a simple figure
##D d$draw(1:10)
##D # change the colour of the polygon 'pol1'
##D d$set("pol1", col="yellow")
##D # change the text
##D d$set("text", "Wow !", col='red', size=3. font=3)
##D 
##D # using figaro with a graphical object
##D # create some test data
##D x1 <- runif(10,0,10)
##D y1 <- runif(10,0,10)
##D x2 <- runif(10,5,15)
##D y2 <- runif(10,5,15)
##D 
##D # create two groups of point data
##D xy1 <- as.pgo(x1,y1,col="red", pch=16, label="Group A")
##D xy2 <- as.pgo(x2,y2, col="blue", pch=17, label="Group B")
##D # combine them
##D xy <- as.go(cpgo(xy1, xy2),xlab="X", ylab="Y")
##D # plot in the conventional way
##D plot(xy)
##D #plot in the figaro way
##D spot <- figaro(plot)
##D spot$draw(xy)
##D # change attributes of points
##D spot$set("points", col=c("khaki","green"))
##D 
##D # some more data
##D a <- 0:360*pi/180
##D ys <-sin(a*a)
##D yc <-cos(a)
##D y2 <- ys+yc+5
##D sw <- as.lgo(a,ys,col="green", label="Sine(a^2)")
##D cw <- as.lgo(a,yc, col="red", lty="dotted", label="Cos(a)")
##D yw <- as.lgo(a,y2,col="blue",label="Cos(a) + Sin(a^2)")
##D lp <- as.go(lines=clgo(sw,cw,yw),xlab="radians", ylab="amplitude")
##D #  draw using figaro
##D wave <- new(plot)
##D wave$draw(lp)
##D # .. and edit
##D wave$set(title="Adding Waveforms")
##D 
##D xylp <- cgo(xy, lp)
##D both <- new(plot)
##D both$draw(xylp)
##D both$set(title="Line and Point graphical object")
##D # add a legend,
##D #     select the location of the bottom left corner of the
##D #     legend box using the pointing device
##D both$legend()
##D both$set("lines", label=c("w1","w2", "w1 + w2"))
## End(Not run)



