### Name: overplotDataset
### Title: Adding another dataset to the current plot
### Aliases: overplotDataset underplotDataset
### Keywords: aplot iplot

### ** Examples

    # Loading two testing datasets
    data(sazava)
    accessVar("sazava")
    
    data(blatna)
    accessVar("blatna")
    setCex(2)
    pokeDataset("blatna",overwrite.warn=FALSE) # Store a version with larger symbols
    
    # Simple binary plot
    peekDataset("blatna")
    binary("SiO2","K2O",col="green",cex=2,xmin=45,xmax=75,ymin=0,ymax=15)
    overplotDataset("sazava",cex=2,col="blue",pch="+",transp=0.5) 
    
    # Simple ternary plot
    peekDataset("blatna")
    ternary("SiO2/10","K2O","Na2O",col="green",cex=2,pch=2)
    overplotDataset("sazava",cex=2,col="red",pch="+",transp=0.5)
    
    # Single classification plots
    peekDataset("blatna")
    plotDiagram("DebonPQ",FALSE,TRUE)
    figRemove()
    overplotDataset("sazava",cex=2,col="darkred",pch=15,transp=0.5)
    
    figRedraw()
    figRemove()
    underplotDataset("sazava",transp=0.5)
    
    plateExtract("PearceGranite",2,main=" ")
    overplotDataset("sazava",cex=2,col="darkred",pch=15,transp=0.5)
    
    # Spiderplots
    # Blatna as std patterns
    peekDataset("blatna")
    spider(WR,"Boynton",1,1000,cex=0,join=TRUE,offset=TRUE,
        centered=FALSE,xrotate=FALSE,xaxs="r")
    overplotDataset("sazava",cex=1.5,pch="+",col="darkgreen",transp=0.5)
 
    # Blatna as gray field
    spider(WR,"Boynton",0.1,1000,field=TRUE,fill.col=TRUE,shaded.col="gray") 
    overplotDataset("sazava",cex=1.5,pch="+",col="darkgreen",transp=0.5)
    
    # A simple plate
    peekDataset("blatna")
    multiple("SiO2",y="K2O,TiO2,Al2O3,FeOt,MgO,CaO,Na2O,K2O,P2O5",nrow=3,ncol=3,main="")
    plateCex(1.8)
    plateCexLab(1.3)
    overplotDataset("sazava",cex=1.5,pch="+",col="darkgreen",transp=0.5,autoscale=TRUE)

    # A user-defined plate of classification diagrams
    peekDataset("blatna")
    multiplePerPage(4,nrow=2,ncol=2,title="A classification plate")
    plotDiagram("DebonPQ",FALSE,FALSE,main=" ")
    plotDiagram("DebonBA",FALSE,FALSE,main=" ")
    plotDiagram("LarocheVolc",FALSE,FALSE,main=" ") 
    plotDiagram("Meschede",FALSE,FALSE,main=" ")
    plateLabelSlots(text=letters,cex=1.5,pos="topleft")
    plateUser(cex=2,col="darkblue",cex.lab=1.2)
    overplotDataset("sazava",cex=2,col=2,pch="+",transp=0.5)

    plateRedraw()
    underplotDataset("sazava",transp=0.5)



