### Name: plateAddReservoirs
### Title: Plate editing: plateAddReservoirs
### Aliases: plateAddReservoirs
### Keywords: aplot color iplot

### ** Examples

    data(blatna)
    accessVar("blatna")

    # Plate of simple binary and ternary plots    
    multiplePerPage(2,ncol=2,nrow=1,title="Testing plateAddReservoirs",dummy=FALSE)
    Plate(1)
    binary("Ba","Sr",new=FALSE,log="xy")
    Plate(2)
    plateExtract("Wood",1,main=" ")
    plateCex(2)
    plateCexLab(1.5)

    # Temporary overplotting with the selected reservoirs (just.draw=TRUE)
    # Sun & McDonough 1989 mantle reservoirs, Taylor & McLennan 1995 Upper/Lower Crust
    reserv<-c("(MORB|EMORB|OIB) McDonough","Upper Crust Taylor 1995","Lower Crust Taylor 1995") 
    reserv.names<-c("NMORB","EMORB","OIB","UCC","LCC") 
    plateAddReservoirs(TRUE,"reservoirs.data",reserv.condition=reserv,
        labs=reserv.names,cex=1.2,col="darkblue",just.draw=TRUE) 
        
    # Clearing
    plateRedraw()

    # Permanent overplotting with a modelled trend
    # Calculate Rayleigh-type fractionation trend and store in a global variable
    ff<-seq(1,0.1,-0.1) # F, amount of melt left
    x<-80*ff^(1.2-1)    # cL for three elements, arbitrary D of 1.2, 2.0 and 1.3
    y<-550*ff^(2.0-1)
    z<-1000*ff^(1.3-1)
    my.trend<-cbind(x,y,z)
    colnames(my.trend)<-c("Rb","Sr","Ba")
    rownames(my.trend)<-ff

    plateAddReservoirs(TRUE,var.name="my.trend",type="o",col="darkgreen",just.draw=FALSE)
    plateRedraw()

    # Plate of spider plots  
    ee<-spider(WR,"NMORB immobile",0.1,1000,pch=1:14,col=1:14,legend=TRUE)
    groupsByLabel("Suite")
    figMulti(nrow=1,ncol=3,plot.symb=TRUE)
    
    reserv<-c("OIB .* McDonough","Lower Crust Taylor 1995") 
    reserv.names<-c("OIB","LCC") 
     
    plateAddReservoirs(FALSE,"reservoirs.data",reserv.condition=reserv,
        labs=reserv.names,cex=2,col="darkgreen")



